@@ -27,7 +27,7 @@
 #include <QObject>
 #include <QQueue>
 #include <QPointer>
-#include <QSet>
+
 
 class QString;
 
@@ -107,7 +107,6 @@ class Q_DECL_EXPORT SensorAgent : public QObject
 
     bool mDaemonOnLine;
     QString mHostName;
-    QSet<SensorRequest> mUnderwayRequests;
 };
 
 /**
@@ -128,14 +127,6 @@ class SensorRequest
     void setId( int );
     int id();
 
-  friend uint qHash(const SensorRequest& sr, uint seed=0) {
-    return qHash(qMakePair(sr.mRequest, qMakePair(sr.mClient, sr.mId)), seed);
-  }
-  friend bool operator==(const SensorRequest& a, const SensorRequest& b) {
-    return a.mRequest == b.mRequest &&
-      a.mClient == b.mClient &&
-      a.mId == b.mId;
-  }
   private:
     QString mRequest;
     SensorClient *mClient = nullptr;
